summaryrefslogtreecommitdiff
path: root/test
diff options
context:
space:
mode:
authorJenkins <jenkins@review.openstack.org>2017-05-10 20:33:38 +0000
committerGerrit Code Review <review@openstack.org>2017-05-10 20:33:38 +0000
commita17e50fd34c9f7865dc30c20700df5715c05f24a (patch)
tree88a4d280bc8dfcb768447ec8aac2050bd59bb85f /test
parent02372409267ab33b4a75aa4fa06923365cbd2f17 (diff)
parent11244e449ffcfcc6fdbd37bc4320a94225161fef (diff)
downloadliberasurecode-a17e50fd34c9f7865dc30c20700df5715c05f24a.tar.gz
Merge "Stop running test_simple_encode_decode_over32 repeatedly"
Diffstat (limited to 'test')
-rw-r--r--test/liberasurecode_test.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/test/liberasurecode_test.c b/test/liberasurecode_test.c
index 566bd48..3f409c3 100644
--- a/test/liberasurecode_test.c
+++ b/test/liberasurecode_test.c
@@ -1887,10 +1887,6 @@ struct testcase testcases[] = {
test_verify_stripe_metadata_frag_idx_invalid,
EC_BACKEND_FLAT_XOR_HD, CHKSUM_CRC32,
.skip = false},
- {"test_simple_encode_decode_over32",
- test_simple_encode_decode_over32,
- EC_BACKEND_JERASURE_RS_VAND, CHKSUM_CRC32,
- .skip = false},
// Jerasure RS Vand backend tests
{"create_and_destroy_backend",
test_create_and_destroy_backend,
@@ -1956,6 +1952,10 @@ struct testcase testcases[] = {
test_verify_stripe_metadata_frag_idx_invalid,
EC_BACKEND_JERASURE_RS_VAND, CHKSUM_CRC32,
.skip = false},
+ {"test_simple_encode_decode_over32_jerasure_rs_vand",
+ test_simple_encode_decode_over32,
+ EC_BACKENDS_MAX, 0, // NB: this is hardcoded to use jerasure RS vand
+ .skip = false},
// Jerasure RS Cauchy backend tests
{"create_and_destroy_backend",
test_create_and_destroy_backend,
@@ -2365,7 +2365,7 @@ int main(int argc, char **argv)
continue;
}
if (testcases[ii].be_id == EC_BACKENDS_MAX) {
/* EC_BACKEND_MAX basically designed for invalid args tests
* and not takes the args so call the function w/o args here */
testcases[ii].function();
fprintf(stdout, "ok %d - %s: %s (idx=%d)\n", num_cases,
@@ -2365,7 +2365,7 @@ int main(int argc, char **argv)
}
if (testcases[ii].be_id == EC_BACKENDS_MAX) {
- /* EC_BACKEND_MAX basically designed for invalid args tests
+ /* EC_BACKENDS_MAX basically designed for invalid args tests
* and not takes the args so call the function w/o args here */
testcases[ii].function();